==> fillets-ng-data-0.7.1.tar.gz: fillets-ng-data-0.7.1/script/barrel/dialogs_cs.lua <==

dialogId("bar-v-videt0", "font_big", "Somebody from Greenpeace should see this.")
dialogStr("To by měli vidět lidi z Greenpeace.")


dialogId("bar-m-videt1", "font_small", "Somebody from Three Miles Island should see this.")
dialogStr("To by měli vidět lidi z Temelína.")


dialogId("bar-v-co", "font_big", "What are we supposed to do with it?")
dialogStr("Ale co s tím budeme dělat?")


dialogId("bar-m-pobit", "font_small", "We have to exterminate all of them. Such abominations have no right to breath the same air... er, water, as we do.")
dialogStr("Musíme je všechny pobít. Takové stvůry nemají právo dýchat stejný vzduch.... é, vodu, jako my.")


dialogId("bar-v-priciny", "font_big", "I think we have to eliminate the cause and not the results.")
dialogStr("Já si myslím, že musíme odstraňovat příčiny a ne následky.")


dialogId("bar-m-no", "font_small", "Well, you may be right.")
dialogStr("No, možná máš pravdu.")


dialogId("bar-v-sud", "font_big", "And the cause is doubtless this giant barrel. We have to get it out somehow.")
dialogStr("A příčina je nepochybně tento olbřímí sud. Musíme ho nějak dostat ven.")


dialogId("bar-m-panb", "font_small", "Yes. Let`s get to work. We can drop it on the Mr. B.`s front yard afterwards.")
dialogStr("Ano. Tak se dejme do práce. Ať ho můžeme hodit panu B. na dvorek.")


dialogId("bar-m-rada", "font_small", "I think I am growing to like them.")
dialogStr("Vlastně je začínám mít docela ráda.")


dialogId("bar-v-kdyby0", "font_big", "If only they wouldn`t stand in our way so much.")
dialogStr("Jen kdyby se nám tu tolik nepletli.")


dialogId("bar-v-kdyby1", "font_big", "If only they were where we need them.")
dialogStr("Jen kdyby byli tam, kde je potřebujeme.")


dialogId("bar-v-sbirka", "font_big", "Such a lovely collection of monstrosities. I`ll be sorry to leave.")
dialogStr("Ta milá sbírka zrůdiček. Bude mi líto odsud odejít.")


dialogId("bar-m-dost0", "font_small", "That won`t happen any time soon.")
dialogStr("Na to máš ještě dost času.")


dialogId("bar-m-dost1", "font_small", "You are going to have plenty of time to enjoy them.")
dialogStr("Bojím se, že ti to ještě dlouho líto být nemusí.")


dialogId("bar-v-lih", "font_big", "If we take them with us and store them in alcohol, we could found ourselves a freak show.")
dialogStr("Kdybychom si je vzali s sebou a naložili do lihu, tak si můžeme otevřít obludárium.")


dialogId("bar-m-fdto", "font_small", "And FDTO isn`t enough for you?")
dialogStr("To ti nestačí FDTO?")


dialogId("bar-x-vypr", "font_white", "I can hear everything!")
dialogStr("Všechno slyším!")


dialogId("bar-m-promin", "font_small", "Sorry, boss. I didn`t mean to offend.")
dialogStr("Promiňte šéfe. Já to tak nemyslela.")


dialogId("bar-m-mutanti", "font_small", "You know, I finally realized that even mutants have a soul.")
dialogStr("Víš, konečně jsem si uvědomila, že i mutanti mají duši.")


dialogId("bar-v-ufouni", "font_big", "Maybe even UFOs can have a soul.")
dialogStr("Možná, že dokonce i ufouni mohou mít duši.")


dialogId("bar-m-zmeni", "font_small", "I think that this level is going to change us forever.")
dialogStr("Myslím, že tahle místnost nás změní navždy.")


dialogId("bar-m-noha", "font_small", "That foot is not only repulsive but also shameless. Just look at it.")
dialogStr("Ta noha je nejen odporná, ale i bezcharakterní. Podívej se na ni.")


dialogId("bar-v-pld", "font_big", "Look at that pld. It looks the same and still it grows more and more repulsive.")
dialogStr("Podívej na toho plda. Vypadá pořád stejně a přitom je pořád odpornější.")


dialogId("bar-m-pudy", "font_small", "But even it harbors some motherly instincts. Look how it cares about the little one.")
dialogStr("Ale i v něm dřímou mateřské pudy. Podívej, jak se stará o to maličké.")


dialogId("bar-v-traverza", "font_big", "Yes. It almost killed it with iron beam.")
dialogStr("Ano. Přizabil ho traverzou.")


dialogId("bar-m-rybka", "font_small", "This fish looks familiar to me.")
dialogStr("Ta rybka je mi odněkud povědomá.")


dialogId("bar-v-fotka", "font_big", "Maybe it was in that photo from the power plant.")
dialogStr("Možná, že byla na té fotografii z elekrárny.")


dialogId("bar-v-krab", "font_big", "The poor crab. So many pincers and no head. Although... maybe he is better off than us.")
dialogStr("Chudák ten krab. Tolik klepet a žádná hlava. I když... možná je mu takhle líp než nám.")


dialogId("bar-m-kachna", "font_small", "No man is alone with a little yellow duck. Not even fish.")
dialogStr("Se žlutou kachničkou není člověk nikdy sám. Ani ryba.")


dialogId("bar-m-barel", "font_small", "This time, our goal is to push out the barrel with that filth.")
dialogStr("Tentokrát je naším úkolem vytlačit ven barel s tím svinstvem.")


dialogId("bar-v-genofond", "font_big", "But we have to leave all those creatures here. They must not harm the genepool of the healthy population.")
dialogStr("A všechny tvory tu musíme nechat! Ať nezkazí genofond zdravé populace.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/barrel/dialogs_cs.lua <==

dialogId("bar-v-videt0", "font_big", "Somebody from Greenpeace should see this.")
dialogStr("To by měli vidět lidi z Greenpeace.")


dialogId("bar-m-videt1", "font_small", "Somebody from Three Miles Island should see this.")
dialogStr("To by měli vidět lidi z Temelína.")


dialogId("bar-v-co", "font_big", "What are we supposed to do with it?")
dialogStr("Ale co s tím budeme dělat?")


dialogId("bar-m-pobit", "font_small", "We have to exterminate all of them. Such abominations have no right to breath the same air... er, water, as we do.")
dialogStr("Musíme je všechny pobít. Takové stvůry nemají právo dýchat stejný vzduch.... é, vodu, jako my.")


dialogId("bar-v-priciny", "font_big", "I think we have to eliminate the cause and not the results.")
dialogStr("Já si myslím, že musíme odstraňovat příčiny a ne následky.")


dialogId("bar-m-no", "font_small", "Well, you may be right.")
dialogStr("No, možná máš pravdu.")


dialogId("bar-v-sud", "font_big", "And the cause is doubtless this giant barrel. We have to get it out somehow.")
dialogStr("A příčina je nepochybně tento olbřímí sud. Musíme ho nějak dostat ven.")


dialogId("bar-m-panb", "font_small", "Yes. Let’s get to work. We can drop it on the Mr. B.’s front yard afterwards.")
dialogStr("Ano. Tak se dejme do práce. Ať ho můžeme hodit panu B. na dvorek.")


dialogId("bar-m-rada", "font_small", "I think I am growing to like them.")
dialogStr("Vlastně je začínám mít docela ráda.")


dialogId("bar-v-kdyby0", "font_big", "If only they wouldn’t stand in our way so much.")
dialogStr("Jen kdyby se nám tu tolik nepletli.")


dialogId("bar-v-kdyby1", "font_big", "If only they were where we need them.")
dialogStr("Jen kdyby byli tam, kde je potřebujeme.")


dialogId("bar-v-sbirka", "font_big", "Such a lovely collection of monstrosities. I’ll be sorry to leave.")
dialogStr("Ta milá sbírka zrůdiček. Bude mi líto odsud odejít.")


dialogId("bar-m-dost0", "font_small", "That won’t happen any time soon.")
dialogStr("Na to máš ještě dost času.")


dialogId("bar-m-dost1", "font_small", "You are going to have plenty of time to enjoy them.")
dialogStr("Bojím se, že ti to ještě dlouho líto být nemusí.")


dialogId("bar-v-lih", "font_big", "If we take them with us and store them in alcohol, we could found ourselves a freak show.")
dialogStr("Kdybychom si je vzali s sebou a naložili do lihu, tak si můžeme otevřít obludárium.")


dialogId("bar-m-fdto", "font_small", "And FDTO isn’t enough for you?")
dialogStr("To ti nestačí FDTO?")


dialogId("bar-x-vypr", "font_white", "I can hear everything!")
dialogStr("Všechno slyším!")


dialogId("bar-m-promin", "font_small", "Sorry, boss. I didn’t mean to offend.")
dialogStr("Promiňte šéfe. Já to tak nemyslela.")


dialogId("bar-m-mutanti", "font_small", "You know, I finally realized that even mutants have a soul.")
dialogStr("Víš, konečně jsem si uvědomila, že i mutanti mají duši.")


dialogId("bar-v-ufouni", "font_big", "Maybe even UFOs can have a soul.")
dialogStr("Možná, že dokonce i ufouni mohou mít duši.")


dialogId("bar-m-zmeni", "font_small", "I think that this level is going to change us forever.")
dialogStr("Myslím, že tahle místnost nás změní navždy.")


dialogId("bar-m-noha", "font_small", "That foot is not only repulsive but also shameless. Just look at it.")
dialogStr("Ta noha je nejen odporná, ale i bezcharakterní. Podívej se na ni.")


dialogId("bar-v-pld", "font_big", "Look at that pld. It looks the same and still it grows more and more repulsive.")
dialogStr("Podívej na toho plda. Vypadá pořád stejně a přitom je pořád odpornější.")


dialogId("bar-m-pudy", "font_small", "But even it harbors some motherly instincts. Look how it cares about the little one.")
dialogStr("Ale i v něm dřímou mateřské pudy. Podívej, jak se stará o to maličké.")


dialogId("bar-v-traverza", "font_big", "Yes. It almost killed it with iron beam.")
dialogStr("Ano. Přizabil ho traverzou.")


dialogId("bar-m-rybka", "font_small", "This fish looks familiar to me.")
dialogStr("Ta rybka je mi odněkud povědomá.")


dialogId("bar-v-fotka", "font_big", "Maybe it was in that photo from the power plant.")
dialogStr("Možná, že byla na té fotografii z elekrárny.")


dialogId("bar-v-krab", "font_big", "The poor crab. So many pincers and no head. Although... maybe he is better off than us.")
dialogStr("Chudák ten krab. Tolik klepet a žádná hlava. I když... možná je mu takhle líp než nám.")


dialogId("bar-m-kachna", "font_small", "No man is alone with a little yellow duck. Not even fish.")
dialogStr("Se žlutou kachničkou není člověk nikdy sám. Ani ryba.")


dialogId("bar-m-barel", "font_small", "This time, our goal is to push out the barrel with that filth.")
dialogStr("Tentokrát je naším úkolem vytlačit ven barel s tím svinstvem.")


dialogId("bar-v-genofond", "font_big", "But we have to leave all those creatures here. They must not harm the genepool of the healthy population.")
dialogStr("A všechny tvory tu musíme nechat! Ať nezkazí genofond zdravé populace.")
